
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;

public class GameWindow extends JFrame implements ActionListener {

	// static variables
	private static Grid matrix;
	private static int rows = 0;
	private static int cols = 0;
	private static int genTime = 0;
	private static boolean running = false;

	// field variables
	private JTextField dimText;
	private JTextField genTimeText;
	private JButton apply;
	private JButton start;
	private JButton stop;
	private JButton clear;
	private JPanel buttonPanel;
	private GridPanel gridPanel;

	// Create game window with text fields to get dimension and generation time,
	// several buttons, and a grid panel to display the cells.
	public GameWindow(String s) {
		super(s); // create window heading
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		setResizable(false);
		// Our window will have two new JPanels: one for input and control
		// buttons, and one for the actual grid display. First make button
		// panel with all the labels, text fields and buttons.
		buttonPanel = new JPanel();
/*
		// label and text field for dimension
		buttonPanel.add(new JLabel(" Rows & Cols: "));
		dimText = new JTextField("30", 3);
		dimText.addActionListener(this);
		buttonPanel.add(dimText);
*/
		// label and text field for generation time (in milliseconds)
		buttonPanel.add(new JLabel(" Gen time (ms): "));
		genTimeText = new JTextField("50", 4);
		buttonPanel.add(genTimeText);
		genTimeText.addActionListener(this);
		// apply button to initialize dimensions and dynamically change
		// generation time.
		apply = new JButton(" Apply ");
		apply.setBackground(Color.LIGHT_GRAY);
		apply.addActionListener(this);
		buttonPanel.add(apply);
		// start button to activate simulation.
		start = new JButton(" Start ");
		start.setBackground(Color.GREEN);
		start.addActionListener(this);
		buttonPanel.add(start);
		// stop button to pause simulation.
		stop = new JButton(" Stop ");
		stop.setBackground(Color.RED);
		stop.addActionListener(this);
		buttonPanel.add(stop);
		// clear button to kill all cells.
		clear = new JButton(" Clear ");
		clear.setBackground(Color.CYAN);
		clear.addActionListener(this);
		buttonPanel.add(clear);
		// Make gridPanel, add buttonPanel and gridPanel to the window, and
		// make it visible.
		gridPanel = new GridPanel();
		Container content = getContentPane();
		content.add(buttonPanel, BorderLayout.NORTH);
		content.add(gridPanel, BorderLayout.CENTER);
		pack();
		setVisible(true);
	}


	// Get the values from text fields and controls the simulation.
	public void actionPerformed(ActionEvent e) {
		if (e.getSource() == apply) {
			// rows = Integer.parseInt(dimText.getText());
			// cols = Integer.parseInt(dimText.getText());
                        cols = rows = 30;
			genTime = Integer.parseInt(genTimeText.getText());
		} else if (e.getSource() == dimText) {
			rows = Integer.parseInt(dimText.getText());
			cols = Integer.parseInt(dimText.getText());
		} else if (e.getSource() == genTimeText) {
			genTime = Integer.parseInt(genTimeText.getText());
		} else if (e.getSource() == start) {
			running = true;
		} else if (e.getSource() == stop) {
			running = false;
		} else if (e.getSource() == clear) {
			running = false;
			if (rows > 0) {
				matrix.clearGrid();
			}
		}
		/*
		 * System.out.println("rows: " + rows + " cols: " + cols + " genTime: "
		 * + genTime + " running: " + running);
		 */
	}


	public static void main(String[] args) throws InterruptedException {
		// make gameWindow
		GameWindow frame = new GameWindow(
				"Conway's Game of Life: Change Gen time at will");
		// Wait for user to enter dimensions.
		while (frame.rows == 0) {
			Thread.sleep(1000);
		}
		// make grid
		matrix = new Grid(frame.rows, frame.cols);
		for (;;) {
			// Loop forever updating the display, changing generations if
			// simulation is active.
			frame.gridPanel.update(matrix);
			if (frame.running) {
				GameLogic.nextGeneration(matrix);
			}
			Thread.sleep(frame.genTime);
		}
	}

}

