
public class Grid {

        // Represent a grid with a 2d array of integers. 0 means the cell is
        // dead, 1 means the cell is alive.  Could maybe use booleans instead
        // of ints, but ints are more convenient for counting neighbors.
	private int[][] matrix;

	// Makes a new 2d array of integers
	public Grid(int rows, int cols) {
		matrix = new int[rows][cols];
		clearGrid();
	}

	public int numRows() {
		return matrix.length;
	}

	public int numCols() {
		return matrix[0].length;
	}

	// Zero the grid so all cells are dead.
	public void clearGrid() {
		for (int row = 0; (row < numRows()); row++) {
			for (int col = 0; (col < numCols()); col++) {
				matrix[row][col] = 0;
			}
		}
	}

        // Check for life at the specified coordinates.  Changes cells outside
        // the boundaries of the matrix to cells inside the bounds by making
        // the matrix wrap around.
	public int lifeAt(int row, int col) {
		if (col >= numCols()) {
			col = 0;
		} else if (col < 0) {
			col = numCols() - 1;
		}
		if (row >= numRows()) {
			row = 0;
		} else if (row < 0) {
			row = numRows() - 1;
		}
		return matrix[row][col];
	}

	// Set a cell at position (row, col) to either alive or dead
	public void setLifeAt(int row, int col, int live) {
		// Should maybe raise exception for out of bounds value?
		matrix[row][col] = live;
	}

        // Counts number of neighbors for each cell.  Since a live neighbor has
        // a value of 1, add up the value of the neighbors and return the total
        // as "count."
	public int countNeighbors(int row, int col) {
		int count = 0;
		count += lifeAt(row - 1, col - 1) + lifeAt(row - 1, col) + lifeAt(row - 1, col + 1);
		count += lifeAt(row, col - 1) + lifeAt(row, col + 1);
		count += lifeAt(row + 1, col - 1) + lifeAt(row + 1, col) + lifeAt(row + 1, col + 1);
		return count;
	}

	// This was used during development to show the matrix.
	public void showMatrix() {
		for (int row = 0; (row < numRows()); row++) {
			System.out.print(row % 10);
			for (int col = 0; (col < numCols()); col++) {
				if (matrix[row][col] == 0) {
					System.out.print(" ");
				} else {
					System.out.print("@");
				}
			}
			System.out.println();
		}
	}

}

