import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JPanel;

public class GridPanel extends JPanel implements MouseListener {


	// The grid display is fixed at 600 pixels.
	final int PANELDIMENSION = 600;
	// The cellSize varies based on the dimensions of the grid.
	private int cellSize;
	private Grid matrix = null;


	// Make the GridPanel and add the MouseListener
	public GridPanel() {
		setBackground(Color.blue);
		setPreferredSize(new Dimension(PANELDIMENSION, PANELDIMENSION));
		addMouseListener(this);
	}


	// Get local reference to matrix, calculate cellSize and call repaint.
	public void update(Grid matrix) {
		this.matrix = matrix;
		cellSize = PANELDIMENSION / matrix.numRows();
		repaint();
	}


	// Updates the grid display by looking at each cell in the matrix and
	// changing the color according to whether its alive or dead.
	public void paintComponent(Graphics g) {
		super.paintComponent(g);
		if (matrix == null) {
			// Don't try to display if it is not ready yet.
			return;
		}
		for (int r = 0; r < matrix.numRows(); r++) {
			for (int c = 0; c < matrix.numCols(); c++) {
				Color color;
				if (matrix.lifeAt(r, c) == 0) {
					color = Color.WHITE;
				} else {
					color = Color.RED;
				}
				g.setColor(color);
				int x = c * cellSize;
				int y = r * cellSize;
				g.fillRect(x, y, cellSize, cellSize);
				g.setColor(Color.BLACK);
				g.drawRect(x, y, cellSize, cellSize);
				if (cellSize > 20) {
					// Double the cell outline if the cells are big.
					g.drawRect(x + 1, y + 1, cellSize - 2, cellSize - 2);
				}
			}
		}
	}


	// Get the mouse position and set the cell to alive.
	public void mouseReleased(MouseEvent e) {
		matrix.setLifeAt(e.getY() / cellSize, e.getX() / cellSize, 1);
		update(matrix);
	}


	// The rest of these are required by the MouseListener interface:
	public void mouseClicked(MouseEvent e) {
	}


	public void mousePressed(MouseEvent e) {
	}


	public void mouseEntered(MouseEvent e) {
	}


	public void mouseExited(MouseEvent e) {
	}

}

